@@ -1,4 +1,4 @@
-"""A media player."""
+"""Play media on your website."""
 
 import web
 
